#!/usr/bin/env python3
from .tradedefender import companies
from .tradedefender import sicpeers
from .tradedefender import stockprice
from .tradedefender import histpricedata
from .tradedefender import histestimates
from .tradedefender import balancesheets
from .tradedefender import incomestatements
from .tradedefender import cashflowstatements
from .tradedefender import optionchain
from .tradedefender import option



#!/usr/bin/env python3

from setuptools import setup

setup(name='tradedefender',
      version='0.1',
      description='Interface for Trade Defender financial data',
      url='https://tradedefender.com',
      author='CJ Black',
      author_email='cj@tradedefender.com',
      license='MIT',
      packages=['tradedefender'],
      install_requires=['requests'],
      zip_safe=False)



#!/usr/bin/env python3
import requests
import json


BASE_URL = "https://api.tradedefender.com/companies"


def strip_option_symbol(symbol):
    outSymbol = ""
    if(symbol is not False):
        for s in symbol:
            if(s.isdigit()):
                break
            else:
                outSymbol = outSymbol + s
        return(outSymbol)
    else:
        return("False")


def parameterize(host, params):
    url = host
    if(params["api_key"] is not False):
        url = host + "?api_key=" + str(params["api_key"])
        del params["api_key"]

    for p in params:
        if(params[p] is not False):
            url = url + "&" + p + "=" + params[p]

    return(url)


def make_request(url):
    response = json.loads(requests.get(url).text)
    return(response)


def companies(app_key=False, symbol=False, order_by=False, columns=False):
    host = BASE_URL
    if(symbol is not False):
        host = BASE_URL + "/" + symbol
    params = {"api_key": app_key,
              "order_by": order_by,
              "columns": columns}
    request_url = parameterize(host, params)
    response = make_request(request_url)
    return(response)


def sicpeers(app_key=False, symbol=False, order_by=False, columns=False):
    host = BASE_URL + "/" + str(symbol) + "/sic-peers"
    params = {"api_key": app_key,
              "order_by": order_by,
              "columns": columns}
    request_url = parameterize(host, params)
    response = make_request(request_url)
    return(response)


def stockprice(app_key=False, symbol=False):
    host = BASE_URL + "/" + str(symbol) + "/price"
    params = {"api_key": app_key}
    request_url = parameterize(host, params)
    response = make_request(request_url)
    return(response)


def histpricedata(app_key=False, symbol=False, start_date=False,
                  end_date=False, order_by=False, columns=False):
    host = BASE_URL + "/" + str(symbol) + "/hist-price-data"
    params = {"api_key": app_key,
              "start_date": start_date,
              "end_date": end_date,
              "order_by": order_by,
              "columns": columns}
    request_url = parameterize(host, params)
    response = make_request(request_url)
    return(response)


def histestimates(app_key=False, symbol=False, start_date=False,
                  end_date=False, order_by=False, columns=False):
    host = BASE_URL + "/" + str(symbol) + "/hist-earnings-and-estimates"
    params = {"api_key": app_key,
              "start_date": start_date,
              "end_date": end_date,
              "order_by": order_by,
              "columns": columns}
    request_url = parameterize(host, params)
    response = make_request(request_url)
    return(response)


def balancesheets(app_key=False, symbol=False, start_date=False,
                  end_date=False, order_by=False, columns=False,
                  period_type=False):
    host = BASE_URL + "/" + str(symbol) + "/hist-balance-sheets"
    params = {"api_key": app_key,
              "start_date": start_date,
              "end_date": end_date,
              "order_by": order_by,
              "columns": columns,
              "period_type": period_type}
    request_url = parameterize(host, params)
    response = make_request(request_url)
    return(response)


def cashflowstatements(app_key=False, symbol=False, start_date=False,
                       end_date=False, order_by=False, columns=False,
                       period_type=False):
    host = BASE_URL + "/" + str(symbol) + "/hist-cash-flow-statements"
    params = {"api_key": app_key,
              "start_date": start_date,
              "end_date": end_date,
              "order_by": order_by,
              "columns": columns,
              "period_type": period_type}
    request_url = parameterize(host, params)
    response = make_request(request_url)
    return(response)


def incomestatements(app_key=False, symbol=False, start_date=False,
                     end_date=False, order_by=False, columns=False,
                     period_type=False):
    host = BASE_URL + "/" + str(symbol) + "/hist-income-statements"
    params = {"api_key": app_key,
              "start_date": start_date,
              "end_date": end_date,
              "order_by": order_by,
              "columns": columns,
              "period_type": period_type}
    request_url = parameterize(host, params)
    response = make_request(request_url)
    return(response)


def optionchain(app_key=False, symbol=False, start_date=False,
                end_date=False, option_type=False, columns=False):
    host = BASE_URL + "/" + str(symbol) + "/options"
    params = {"api_key": app_key,
              "start_date": start_date,
              "type": option_type,
              "end_date": end_date,
              "columns": columns}
    request_url = parameterize(host, params)
    response = make_request(request_url)
    return(response)


def option(app_key=False, symbol=False, columns=False):
    option_symbol = symbol
    symbol = strip_option_symbol(option_symbol)
    host = BASE_URL + "/" + str(symbol) + "/options/" + str(option_symbol)
    params = {"api_key": app_key,
              "columns": columns}
    request_url = parameterize(host, params)
    response = make_request(request_url)
    return(response)



#!/usr/bin/env python3
import sys
import json
import datetime
import tradedefender

def execute_test(api_key):
    today = datetime.datetime.now()
    beforeToday = today - datetime.timedelta(days=500)
    afterToday = today + datetime.timedelta(days=500)
    today = today.strftime("%Y-%m-%d")
    beforeToday = beforeToday.strftime("%Y-%m-%d")
    afterToday = afterToday.strftime("%Y-%m-%d")

    testResults =   {"companies":"clean",
                    "sicpeers":"clean",
                    "stockprice":"clean",
                    "histpricedata":"clean",
                    "histestimates":"clean",
                    "balancesheets":"clean",
                    "cashflowstatements":"clean",
                    "incomestatements":"clean",
                    "optionchain":"clean",
                    "option":"clean"}
    #companies
    result = tradedefender.companies(app_key=api_key, symbol="AAPL", order_by="asc", columns="ticker,company_name,company_name_2,exchange,sec_cik")
    if("errors" in result):
        testResults["companies"] = result

    #sicpeers
    result = tradedefender.sicpeers(app_key=api_key, symbol="AAPL", order_by="asc", columns="ticker,company_name,company_name_2,exchange,sec_cik")
    if("errors" in result):
        testResults["sicpeers"] = result

    #stockprice
    result = tradedefender.stockprice(app_key=api_key, symbol="AAPL")
    if("errors" in result):
        testResults["stockprice"] = result

    #histpricedata
    result = tradedefender.histpricedata(app_key=api_key, symbol="AAPL", start_date=beforeToday, end_date=today, order_by="asc", columns="date,adjusted_close")
    if("errors" in result):
        testResults["histpricedata"] = result

    #histestimates
    result = tradedefender.histestimates(app_key=api_key, symbol="AAPL", start_date=beforeToday, end_date=today, order_by="asc", columns="date_announced,eps_act")
    if("errors" in result):
        testResults["histestimates"] = result

    #balancesheets
    result = tradedefender.balancesheets(app_key=api_key, symbol="AAPL", start_date=beforeToday, end_date=today, order_by="asc", columns="per_end_date", period_type="Q")
    if("errors" in result):
        testResults["balancesheets"] = result

    #cashflowstatements
    result = tradedefender.incomestatements(app_key=api_key, symbol="AAPL", start_date=beforeToday, end_date=today, order_by="asc", columns="per_end_date", period_type="Q")
    if("errors" in result):
        testResults["incomestatements"] = result

    #incomestatements
    result = tradedefender.cashflowstatements(app_key=api_key, symbol="AAPL", start_date=beforeToday, end_date=today, order_by="asc", columns="per_end_date", period_type="Q")
    if("errors" in result):
        testResults["cashflowstatements"] = result

    #optionchain
    result = tradedefender.optionchain(app_key=api_key, symbol="AAPL", start_date=today, end_date=afterToday, option_type="calls", columns="symbol,strike_price,delta,gamma,theta")
    option_symbol = ""
    if("errors" in result):
        testResults["optionchain"] = result
    else:
        option_symbol = result["data"][0]["calls"][0]["symbol"]

    #option
    result = tradedefender.option(app_key=api_key, symbol=option_symbol, columns="strike_price,delta,gamma,theta")
    if("errors" in result):
        testResults["option"] = result

    return(testResults)

if __name__ == "__main__":
    if(sys.version_info[0]>=3):
        api_key = input("Enter App Key: ")
    else:
        api_key = raw_input("Enter App Key: ")

    print(execute_test(api_key))
